==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiCore/QAbstractFileEngineHandler_shell.cpp <==
#include "QAbstractFileEngineHandler_shell.h"
#include <QtJambi/Cast>

void deleter_QAbstractFileEngineHandler(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAbstractFileEngineHandler")
    QAbstractFileEngineHandler *_ptr = reinterpret_cast<QAbstractFileEngineHandler *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAbstractFileEngineHandler_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAbstractFileEngineHandler_shell) ); }

jmethodID QAbstractFileEngineHandler_shell::__shell_javaMethod(int pos) const { return QAbstractFileEngineHandler_shell::__shell()->javaMethod(typeid(QAbstractFileEngineHandler), pos); }

// emitting (writeShellConstructor)
QAbstractFileEngineHandler_shell::QAbstractFileEngineHandler_shell()
    : QAbstractFileEngineHandler()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAbstractFileEngineHandler::QAbstractFileEngineHandler_shell()", QAbstractFileEngineHandler_shell::__shell())
    QAbstractFileEngineHandler_shell::__shell()->constructed(typeid(QAbstractFileEngineHandler));
}

// emitting (writeShellDestructor)
QAbstractFileEngineHandler_shell::~QAbstractFileEngineHandler_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAbstractFileEngineHandler::~QAbstractFileEngineHandler()", QAbstractFileEngineHandler_shell::__shell())
    QAbstractFileEngineHandler_shell::__shell()->destructed(typeid(QAbstractFileEngineHandler));
}

void QAbstractFileEngineHandler_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAbstractFileEngineHandler_shell*>(ptr)->QAbstractFileEngineHandler_shell::__shell()->tryDeleteShell(typeid(QAbstractFileEngineHandler));
}

// emitting Virtual overrides (virtualFunctions)
QAbstractFileEngine* QAbstractFileEngineHandler_shell::create(const QString& fileName0) const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAbstractFileEngineHandler::create(QString)const", QAbstractFileEngineHandler_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QAbstractFileEngine*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractFileEngineHandler_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jstring __java_fileName0 = qtjambi_cast<jstring>(__jni_env, fileName0);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_fileName0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QAbstractFileEngine* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QAbstractFileEngineHandler_shell::__shell()->warnForMethod("QAbstractFileEngineHandler::create(QString)const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAbstractFileEngineHandler::create(QString)const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return nullptr;
        }
    }else{
        return nullptr;
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QAbstractFileEngineHandler_access::__qt_create_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring fileName0) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QString  __qt_fileName0 = qtjambi_cast<QString >(__jni_env, fileName0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAbstractFileEngineHandler::create(const QString & fileName) const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAbstractFileEngineHandler::create(const QString & fileName) const.";
    } else {
        QAbstractFileEngine* __qt_return_value = create(__qt_fileName0);
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QAbstractFileEngineHandler()
void __qt_construct_QAbstractFileEngineHandler_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAbstractFileEngineHandler()")
    Q_UNUSED(__java_arguments)
    QAbstractFileEngineHandler *__qt_this = new(__qtjambi_ptr) QAbstractFileEngineHandler_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QAbstractFileEngineHandler_shell
void __qt_destruct_QAbstractFileEngineHandler(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAbstractFileEngineHandler")
    reinterpret_cast<QAbstractFileEngineHandler_shell*>(ptr)->~QAbstractFileEngineHandler_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAbstractFileEngineHandler::QAbstractFileEngineHandler()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QAbstractFileEngineHandler_initialize_1native__Lio_qt_core_internal_QAbstractFileEngineHandler_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAbstractFileEngineHandler::QAbstractFileEngineHandler()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAbstractFileEngineHandler_0, sizeof(QAbstractFileEngineHandler_shell), typeid(QAbstractFileEngineHandler), true, &deleter_QAbstractFileEngineHandler, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAbstractFileEngineHandler::create(QString)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QAbstractFileEngineHandler_00024ConcreteWrapper_create_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring fileName0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QAbstractFileEngineHandler *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractFileEngineHandler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractFileEngineHandler::create(QString)const", __qt_this)
        __java_return_value = static_cast<const QAbstractFileEngineHandler_access*>(__qt_this)->__qt_create_cref_QString_constfct(__jni_env, __this_nativeId, fileName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAbstractFileEngineHandler(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QAbstractFileEngineHandler>("QAbstractFileEngineHandler", "io/qt/core/internal/QAbstractFileEngineHandler");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "create", "(Ljava/lang/String;)Lio/qt/core/internal/QAbstractFileEngine;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QAbstractFileEngineHandler, {
        ConstructorInfo(&__qt_construct_QAbstractFileEngineHandler_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAbstractFileEngineHandler);
    registerSizeOfShell(typeId, sizeof(QAbstractFileEngineHandler_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiCore/QAbstractFileEngineHandler_shell.cpp <==
#include "QAbstractFileEngineHandler_shell.h"
#include <QtJambi/Cast>

void deleter_QAbstractFileEngineHandler(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAbstractFileEngineHandler")
    QAbstractFileEngineHandler *_ptr = reinterpret_cast<QAbstractFileEngineHandler *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAbstractFileEngineHandler_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAbstractFileEngineHandler_shell) ); }

jmethodID QAbstractFileEngineHandler_oshell::__shell_javaMethod(int pos) const { return QAbstractFileEngineHandler_shell::__shell()->javaMethod(typeid(QAbstractFileEngineHandler), pos); }

// emitting (writeShellDestructor)
QAbstractFileEngineHandler_shell::~QAbstractFileEngineHandler_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAbstractFileEngineHandler::~QAbstractFileEngineHandler()", this)
    QAbstractFileEngineHandler_shell::__shell()->destructed(typeid(QAbstractFileEngineHandler));
}

// emitting (writeShellConstructor)
QAbstractFileEngineHandler_shell::QAbstractFileEngineHandler_shell()
    : QAbstractFileEngineHandler()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAbstractFileEngineHandler::QAbstractFileEngineHandler_shell()", this)
    QAbstractFileEngineHandler_shell::__shell()->constructed(typeid(QAbstractFileEngineHandler));
}

void QAbstractFileEngineHandler_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAbstractFileEngineHandler_oshell*>(ptr)->QAbstractFileEngineHandler_oshell::__shell()->tryDeleteShell(typeid(QAbstractFileEngineHandler));
}

// emitting Virtual overrides (virtualFunctions)
QAbstractFileEngine* QAbstractFileEngineHandler_oshell::create(const QString& fileName0) const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAbstractFileEngineHandler::create(QString)const", this)
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QAbstractFileEngine*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractFileEngineHandler_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jstring __java_fileName0 = qtjambi_cast<jstring>(__jni_env, fileName0);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_fileName0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QAbstractFileEngine*>(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnershipAndInvalidate(__jni_env, __java_return_value);
                } else {
                    QAbstractFileEngineHandler_shell::__shell()->warnForMethod("QAbstractFileEngineHandler::create(QString)const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAbstractFileEngineHandler::create(QString)const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return nullptr;
        }
    }else{
        return nullptr;
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QAbstractFileEngineHandler_access::__qt_create_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring fileName0) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QString  __qt_fileName0 = qtjambi_cast<QString>(__jni_env, fileName0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAbstractFileEngineHandler::create(const QString & fileName) const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAbstractFileEngineHandler::create(const QString & fileName) const.";
    } else {
        QAbstractFileEngine* __qt_return_value = create(__qt_fileName0);
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QAbstractFileEngineHandler()
void __qt_construct_QAbstractFileEngineHandler(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAbstractFileEngineHandler()")
    Q_UNUSED(__java_arguments)
    QAbstractFileEngineHandler *__qt_this = new(__qtjambi_ptr) QAbstractFileEngineHandler_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QAbstractFileEngineHandler::QAbstractFileEngineHandler()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QAbstractFileEngineHandler_initialize_1native__Lio_qt_core_internal_QAbstractFileEngineHandler_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAbstractFileEngineHandler::QAbstractFileEngineHandler()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAbstractFileEngineHandler, sizeof(QAbstractFileEngineHandler_shell), typeid(QAbstractFileEngineHandler), 0, true, &deleter_QAbstractFileEngineHandler, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QAbstractFileEngineHandler_shell
void __qt_destruct_QAbstractFileEngineHandler(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAbstractFileEngineHandler")
    reinterpret_cast<QAbstractFileEngineHandler_shell*>(ptr)->~QAbstractFileEngineHandler_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAbstractFileEngineHandler::create(QString)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QAbstractFileEngineHandler_00024ConcreteWrapper_create_1native_1cref_1QString_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring fileName0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QAbstractFileEngineHandler *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractFileEngineHandler>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractFileEngineHandler::create(QString)const", __this_nativeId)
        __java_return_value = static_cast<const QAbstractFileEngineHandler_access*>(__qt_this)->__qt_create_cref_QString_constfct(__jni_env, __this_nativeId, fileName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAbstractFileEngineHandler(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QAbstractFileEngineHandler>("QAbstractFileEngineHandler", "io/qt/core/internal/QAbstractFileEngineHandler");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "create", "(Ljava/lang/String;)Lio/qt/core/internal/QAbstractFileEngine;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QAbstractFileEngineHandler, {
        ConstructorInfo(&__qt_construct_QAbstractFileEngineHandler, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAbstractFileEngineHandler);
    registerSizeOfShell(typeId, sizeof(QAbstractFileEngineHandler_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
